@@ -76,6 +76,8 @@ app_ui <- function(request) {
                                   selectInput("distance", "distance:", 
                                               c("dN", "dS", 
                                                 "dN_vs_dS")),
+                                  selectInput("xory", "axis:", 
+                                              c("Y", "X")),
                                   selectInput("method", "method:", 
                                               c("rms", "rsquared", 
                                                 "correlation")),
@@ -86,6 +88,7 @@ app_ui <- function(request) {
                                             "line.color:", value = "blue"),
                                   actionButton("exclude_toggle", 
                                                "Toggle points"),
+                                  actionButton("autodele", "autodele"),
                                   actionButton("exclude_reset", "Reset"),
                                   checkboxInput("update_data", 
                                                 "live updates", FALSE)),
